@@ -2,22 +2,20 @@ from django.conf.urls import patterns, url
 
 
 urlpatterns = patterns(
-    url(r'^(?P<username>[^/]+)/forms/(?P<id_string>[^/]+)/sms_submission/(?P<s'
-        'ervice>[a-z]+)/?$',
+    url(r'forms/(?P<id_string>[^/]+)/sms_submission/(?P<service>[a-z]+)/?$',
         'sms_support.providers.import_submission_for_form',
         name='sms_submission_form_api'),
-    url(r'^(?P<username>[^/]+)/forms/(?P<id_string>[^/]+)/sms_submission$',
+    url(r'forms/(?P<id_string>[^/]+)/sms_submission$',
         'sms_support.views.import_submission_for_form',
         name='sms_submission_form'),
-    url(r"^(?P<username>[^/]+)/sms_submission/(?P<service>[a-z]+)/?$",
+    url(r"sms_submission/(?P<service>[a-z]+)/?$",
         'sms_support.providers.import_submission',
         name='sms_submission_api'),
-    url(r'^(?P<username>[^/]+)/forms/(?P<id_string>[^/]+)/sms_multiple_submiss'
-        'ions$',
+    url(r'forms/(?P<id_string>[^/]+)/sms_multiple_submissions$',
         'sms_support.views.import_multiple_submissions_for_form',
         name='sms_submissions_form'),
-    url(r"^(?P<username>[^/]+)/sms_multiple_submissions$",
+    url(r"sms_multiple_submissions$",
         'sms_support.views.import_multiple_submissions',
         name='sms_submissions'),
-    url(r"^(?P<username>[^/]+)/sms_submission$",
+    url(r"sms_submission$",
         'sms_support.views.import_submission', name='sms_submission'))
